Cheetah.ImportHooks module — Cheetah3 - The Python-Powered Template Engine

# Cheetah.ImportHooks module

Provides some import hooks to allow Cheetah’s .tmpl files to be imported directly like Python .py modules.

To use these:
  import Cheetah.ImportHooks Cheetah.ImportHooks.install()

class `Cheetah.ImportHooks.` `CheetahDirOwner`(path)

  Bases: `Cheetah.ImportManager.DirOwner`

  `getmod`(name)
  `templateFileExtensions` = ('.tmpl',)

`Cheetah.ImportHooks.` `install`(templateFileExtensions=('.tmpl', ))

  Install the Cheetah Import Hooks

`Cheetah.ImportHooks.` `setCacheDir`(cacheDir)

`Cheetah.ImportHooks.` `uninstall`()

  Uninstall the Cheetah Import Hooks